Documentation
¶
Index ¶
- Variables
- func Close(c io.Closer)
- func ExistEnv(key string) bool
- func Exists(path string, checks ...func(os.FileInfo) bool) bool
- func ExistsDevice(path string) bool
- func ExistsDir(path string) bool
- func ExistsFile(path string) bool
- func ExistsLink(path string) bool
- func ExistsSocket(path string) bool
- func ExpandEnv(key string, def ...string) string
- func Getenv(key string, def ...string) string
- func Open(path string) (*os.File, error)
- type MmapFile
Constants ¶
This section is empty.
Variables ¶
var ErrPageFault = errors.New("page fault occurred while reading from memory map")
Functions ¶
func ExistsDevice ¶
ExistsDevice checks if the given path exists and is a device.
func ExistsFile ¶
ExistsFile checks if the given path exists and is a regular file.
func ExistsLink ¶
ExistsLink checks if the given path exists and is a symbolic link.
func ExistsSocket ¶
ExistsSocket checks if the given path exists and is a socket.
Types ¶
type MmapFile ¶
type MmapFile struct {
// contains filtered or unexported fields
}
func OpenMmapFile ¶
Click to show internal directories.
Click to hide internal directories.